@@ -19,10 +19,10 @@ from openstack import exceptions as sdk_exc
 from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib import utils
+from oslo_utils import strutils
 import six
 
 from senlinclient.common.i18n import _
-from senlinclient.common.i18n import _LI
 from senlinclient.common import utils as senlin_utils
 
 
@@ -314,10 +314,10 @@ class DeleteNode(command.Command):
                 if not prompt_response.startswith('y'):
                     return
         except KeyboardInterrupt:  # Ctrl-c
-            self.log.info(_LI('Ctrl-c detected.'))
+            self.log.info('Ctrl-c detected.')
             return
         except EOFError:  # Ctrl-d
-            self.log.info(_LI('Ctrl-d detected'))
+            self.log.info('Ctrl-d detected')
             return
 
         result = {}
@@ -365,6 +365,13 @@ class RecoverNode(command.Command):
 
     def get_parser(self, prog_name):
         parser = super(RecoverNode, self).get_parser(prog_name)
+        parser.add_argument(
+            '--check',
+            metavar='<boolean>',
+            default=False,
+            help=_('Whether the node(s) should check physical resource status '
+                   'before doing node recover. Default is false')
+        )
         parser.add_argument(
             'node',
             metavar='<node>',
@@ -376,11 +383,60 @@ class RecoverNode(command.Command):
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)", parsed_args)
         senlin_client = self.app.client_manager.clustering
+
+        params = {
+            'check': strutils.bool_from_string(parsed_args.check, strict=True)
+        }
+
         for nid in parsed_args.node:
             try:
-                resp = senlin_client.recover_node(nid)
+                resp = senlin_client.recover_node(nid, **params)
             except sdk_exc.ResourceNotFound:
                 raise exc.CommandError(_('Node not found: %s') % nid)
             print('Node recover request on node %(nid)s is accepted by '
                   'action %(action)s.'
                   % {'nid': nid, 'action': resp['action']})
+
+
+class NodeOp(command.Lister):
+    """Perform an operation on a node."""
+    log = logging.getLogger(__name__ + ".NodeOp")
+
+    def get_parser(self, prog_name):
+        parser = super(NodeOp, self).get_parser(prog_name)
+        parser.add_argument(
+            '--operation',
+            metavar='<operation>',
+            required=True,
+            help=_('Operation to be performed on the node.')
+        )
+        parser.add_argument(
+            '--params',
+            metavar='<key1=value1;key2=value2...>',
+            help=_("Parameters to for the specified operation. "
+                   "This can be specified multiple times, or once with "
+                   "parameters separated by a semicolon."),
+            action="append"
+        )
+        parser.add_argument(
+            'node',
+            metavar='<node>',
+            help=_('ID or name the node operate on.')
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        self.log.debug("take_action(%s)", parsed_args)
+        senlin_client = self.app.client_manager.clustering
+        nid = parsed_args.node
+        if parsed_args.params:
+            params = senlin_utils.format_parameters(parsed_args.params)
+        else:
+            params = {}
+
+        try:
+            resp = senlin_client.perform_operation_on_node(
+                nid, parsed_args.operation, **params)
+            print('Request accepted by action: %s' % resp['action'])
+        except sdk_exc.ResourceNotFound:
+            raise exc.CommandError(_('Node not found: %s') % nid)
